All of lore.kernel.org
 help / color / mirror / Atom feed
From: Edward Shishkin <edward.shishkin@gmail.com>
To: Andrew Morton <akpm@linux-foundation.org>,
	ReiserFS Development List <reiserfs-devel@vger.kernel.org>
Subject: [patch 4/6] reiser4: remove inode_setattr
Date: Wed, 07 Jul 2010 02:21:24 +0200	[thread overview]
Message-ID: <4C33C884.6050602@gmail.com> (raw)

[-- Attachment #1: Type: text/plain, Size: 1 bytes --]



[-- Attachment #2: reiser4-remove-inode_setattr.patch --]
[-- Type: text/plain, Size: 972 bytes --]

Adjust reiser4 to vfs changes:
inode_setattr() has been removed.

Signed-off-by: Edward Shishkin <edward.shishkin@gmail.com>
---
 fs/reiser4/plugin/inode_ops.c |   10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

--- mmotm.orig/fs/reiser4/plugin/inode_ops.c
+++ mmotm/fs/reiser4/plugin/inode_ops.c
@@ -446,7 +446,9 @@ int reiser4_setattr_common(struct dentry
 	assert("nikita-3119", !(attr->ia_valid & ATTR_SIZE));
 
 	/*
 	 * grab disk space and call standard inode_setattr().
 	 */
 	result = setattr_reserve(reiser4_tree_by_inode(inode));
 	if (!result) {
@@ -460,9 +462,9 @@ int reiser4_setattr_common(struct dentry
 				return result;
 			}
 		}
-		result = inode_setattr(inode, attr);
-		if (!result)
-			reiser4_update_sd(inode);
+		setattr_copy(inode, attr);
+		mark_inode_dirty(inode);
+		result = reiser4_update_sd(inode);
 	}
 
 	context_set_commit_async(ctx);
@@ -446,7 +446,9 @@ int reiser4_setattr_common(struct dentry
 
 	/*
-	 * grab disk space and call standard inode_setattr().
+	 * grab disk space and call standard
+	 * setattr_copy();
+	 * mark_inode_dirty().
 	 */
 	result = setattr_reserve(reiser4_tree_by_inode(inode));

                 reply	other threads:[~2010-07-07  0:21 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=4C33C884.6050602@gmail.com \
    --to=edward.shishkin@gmail.com \
    --cc=akpm@linux-foundation.org \
    --cc=reiserfs-devel@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.